API docs for “spamfighter.test.test_plugin.PluginTestCase”

# Class s.t.t.PluginTestCase(unittest.TestCase):

Part of spamfighter.test.test_plugin View Source View In Hierarchy

Тест на `spamfighter.plugin.loadPlugin`.

Method | testLoadPlugin | Undocumented
Method | testLoadPluginNotFound | Undocumented
Method | testLoadPluginAmbiguity | Undocumented

def testLoadPlugin(self): (source)
Undocumented
def testLoadPluginNotFound(self): (source)
Undocumented
def testLoadPluginAmbiguity(self): (source)
Undocumented